import React, { useEffect, useState } from "react";
import { DataGrid, GridColDef, GridCellEditStopParams } from "@mui/x-data-grid";
import { DewarsService } from "../../openapi";

interface SampleSpreadsheetProps {
    dewarId: number; // Selected Dewar's ID
}

const SampleSpreadsheet: React.FC<SampleSpreadsheetProps> = ({ dewarId }) => {
    const [rows, setRows] = useState<any[]>([]); // Rows for the grid
    const [columns, setColumns] = useState<GridColDef[]>([]); // Columns for the grid

    // Fetch rows and columns related to the given Dewar ID
    useEffect(() => {
        if (!dewarId) {
            console.error("Invalid or missing Dewar ID");
            return;
        }

        const fetchSamples = async () => {
    try {
        const response = await DewarsService.getDewarSamplesDewarsDewarsDewarIdSamplesGet(dewarId);
        const dewarData = response; // Assume response is already in correct structure

        // Transform pucks and samples into rows for the grid
        const allRows = [];
        dewarData.pucks.forEach((puck: any) => {
            puck.samples.forEach((sample: any) => {
                allRows.push({
                    id: sample.id,
                    puckId: puck.id,
                    puckName: puck.name,
                    puckType: puck.type,
                    dewarName: dewarData.dewar.dewar_name,
                    position: sample.position,
                    crystalName: sample.sample_name,
                    proteinName: sample.proteinname,
                    priority: sample.priority,
                    comments: sample.comments,
                });
            });
        });
        setRows(allRows);

        // Define table columns if not already set
        setColumns([
            { field: "dewarName", headerName: "Dewar Name", width: 150, editable: false }, // Display Dewar Name
            { field: "puckName", headerName: "Puck Name", width: 150 },
            { field: "puckType", headerName: "Puck Type", width: 150 },
            { field: "crystalName", headerName: "Crystal Name", width: 200, editable: true },
            { field: "proteinName", headerName: "Protein Name", width: 200, editable: true },
            { field: "position", headerName: "Position", width: 100, editable: true , type: "number"},
            { field: "priority", headerName: "Priority", width: 100, editable: true, type: "number" },
            { field: "comments", headerName: "Comments", width: 300, editable: true },
        ]);
    } catch (error) {
        console.error("Error fetching dewar samples:", error);
    }
};

        fetchSamples();
    }, [dewarId]);

    // Handle cell editing to persist changes to the backend
    const handleCellEditStop = async (params: GridCellEditStopParams) => {
        const { id, field, value } = params;
        try {
            // Example: Replace with a proper OpenAPI call if available
            await DewarsService.updateSampleData(id as number, { [field]: value }); // Assuming this exists
            console.log("Updated successfully");
        } catch (error) {
            console.error("Error saving data:", error);
        }
    };

    return (
        <div style={{ height: 500, width: "100%" }}>
            <DataGrid
                rows={rows}
                columns={columns}
                pageSize={10}
                onCellEditStop={handleCellEditStop}
            />
        </div>
    );
};

export default SampleSpreadsheet;